package com.jz.manage.moduls.controller.customer;

import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.Constants;
import com.jz.common.utils.Result;
import com.jz.common.utils.StatusCode;
import com.jz.manage.moduls.controller.BaseController;
import com.jz.manage.moduls.controller.customer.bean.dto.CompanyDetailsDto;
import com.jz.manage.moduls.controller.customer.bean.dto.EnterpriseAuditDto;
import com.jz.manage.moduls.controller.customer.bean.request.EnterpriseAuditRequest;
import com.jz.manage.moduls.service.DepartmentService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * 企业(Department)表控制层
 *
 * @author Bellamy
 * @since 2020-12-01 10:41:35
 */
@RestController
@RequestMapping("department")
@Api(tags = "企业api")
public class DepartmentController extends BaseController {
    /**
     * 服务对象
     */
    @Autowired
    private DepartmentService departmentService;

    /**
     * 条件分页查询企业审核信息
     * @param auditRequest
     * @param req
     * @return
     * @throws Exception
     */
    @PostMapping(value = "/findList")
    @ApiOperation(value = "条件分页查询企业审核信息")
    public PageInfoResponse<EnterpriseAuditDto> findList(@RequestBody EnterpriseAuditRequest auditRequest, HttpServletRequest req) throws Exception {
        PageInfoResponse<EnterpriseAuditDto> pageInfo = new PageInfoResponse<>();
        try {
            pageInfo = departmentService.findList(auditRequest, req);
        }catch (Exception e) {
            pageInfo.setMessage("查询失败");
            pageInfo.setCode(Constants.FAILURE_CODE);
            e.printStackTrace();
        }
        return pageInfo;
    }

    @GetMapping(value = "/{id}")
    @ApiOperation(value = "主键查询用户企业详情信息")
    public Result<CompanyDetailsDto> selectById(@PathVariable(value = "id") String id, HttpServletRequest req) {
        if (id != null) {
            CompanyDetailsDto companyDetails = departmentService.selectById(Long.valueOf(id));
            return new Result<CompanyDetailsDto>(true, "查询企业详情成功！", StatusCode.OK, companyDetails);
        }
        return new Result<CompanyDetailsDto>(false, "查询企业详情失败！", StatusCode.ERROR);
    }
}