package com.jz.manage.moduls.service.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.Constants;
import com.jz.common.entity.Department;
import com.jz.manage.moduls.controller.customer.bean.dto.CompanyDetailsDto;
import com.jz.manage.moduls.controller.customer.bean.dto.EnterpriseAuditDto;
import com.jz.manage.moduls.controller.customer.bean.request.EnterpriseAuditRequest;
import com.jz.manage.moduls.controller.goods.bean.dto.DataGoodsDto;
import com.jz.manage.moduls.mapper.DepartmentDao;
import com.jz.manage.moduls.service.DepartmentService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 企业(TDepartment)表服务实现类
 *
 * @author Bellamy
 * @since 2020-12-01 10:41:35
 */
@Service("departmentService")
public class DepartmentServiceImpl implements DepartmentService {
    @Autowired
    private DepartmentDao tDepartmentDao;

    /**
     * 条件查询企业审核信息列表
     *
     * @param auditRequest
     * @param req
     * @return
     */
    @Override
    public PageInfoResponse<EnterpriseAuditDto> findList(EnterpriseAuditRequest auditRequest, HttpServletRequest req) {
        PageInfoResponse<EnterpriseAuditDto> pageInfoResponse = new PageInfoResponse<>();
        Map<String, Object> param = new HashMap<>();

        // 企业地址
        if (!StringUtils.isEmpty(auditRequest.getRegisteredAddress())) {
            param.put("registeredAddress", auditRequest.getRegisteredAddress());
        }

        // 企业名
        if (!StringUtils.isEmpty(auditRequest.getDepartmentName())) {
            param.put("departmentName", auditRequest.getDepartmentName());
        }

        // 联系人电话
        if (auditRequest.getCustomerPhone() != null) {
            param.put("customerPhone", auditRequest.getCustomerPhone());
        }

        // 审核状态
        if (!StringUtils.isEmpty(auditRequest.getAuditStatus())) {
            param.put("auditStatus", auditRequest.getAuditStatus());
        }
        PageHelper.startPage(auditRequest.getPageNum(), auditRequest.getPageSize());
        List<EnterpriseAuditDto> list = tDepartmentDao.findList(param);
        PageInfo<EnterpriseAuditDto> pageInfo = new PageInfo<>(list);

        pageInfoResponse.setCode(Constants.SUCCESS_CODE);
        pageInfoResponse.setMessage("查询成功");
        pageInfoResponse.setData(pageInfo);
        return pageInfoResponse;
    }

    /**
     * 主键获取用户企业详情信息
     *
     * @param id
     * @return
     */
    @Override
    public CompanyDetailsDto selectById(Long id) {
        CompanyDetailsDto CompanyDetails = tDepartmentDao.selectById(id);
        return CompanyDetails;
    }
}